/** Copyright 2012 VMware, Inc. All rights reserved. -- VMware Confidential */

package com.vmware.samples.test.chassisRack;

import java.net.URI;

import org.testng.Assert;
import org.testng.annotations.Test;

import com.vmware.vise.data.query.QuerySpec;
import com.vmware.vise.data.query.RelationalConstraint;
import com.vmware.vise.data.query.RequestSpec;
import com.vmware.vise.data.query.ResultSet;
import com.vmware.samples.chassisRackVSphere.ChassisRackVSphereDataAdapter;
import com.vmware.samples.test.chassisRack.mock.MockDataService;
import com.vmware.samples.test.chassisRack.mock.MockDataService.Host;
import com.vmware.samples.test.chassisRack.mock.MockVimObjRefSvc;

public class DataAdapterTest {

   private static final int CHASSIS_COUNT = 4;
   private static final int RACK_COUNT = 2;
   private static final int RACK_PER_CHASSIS = 1;
   private static final int CHASSIS_PER_HOST = 1;

   private ChassisRackVSphereDataAdapter _adpater =
         new ChassisRackVSphereDataAdapter(
               new MockDataService(5),
               null,
               new MockVimObjRefSvc(),
               null);

   private URI _chassis;
   private URI _rack;
   private Host _host;

   @Test
   public void getAllRacks() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.RACK_TYPE,
            new String[] {"name", "location"});
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length == RACK_COUNT);
      // save for later use
      _rack = (URI)result.items[0].resourceObject;
   }

   @Test
   public void getRackCount() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.RACK_TYPE,
            new String[] {});
      qrySpc.resultSpec.maxResultCount = 0;
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.totalMatchedObjectCount == RACK_COUNT);
      Assert.assertTrue(result.items == null || result.items.length == 0);
   }

   @Test
   public void getAllChassis() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.CHASSIS_TYPE,
            new String[] {"name", "location"});
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length == CHASSIS_COUNT);
      // save for later use
      _chassis = (URI)result.items[0].resourceObject;
   }

   @Test
   public void getChassisCount() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.CHASSIS_TYPE,
            new String[] {});
      qrySpc.resultSpec.maxResultCount = 0;
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.totalMatchedObjectCount == CHASSIS_COUNT);
      Assert.assertTrue(result.items == null || result.items.length == 0);
   }

   @Test(dependsOnMethods = { "getAllChassis" })
   public void getRackGivenChassis() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.RACK_TYPE,
            "rack",
            _chassis,
            new String[] {"name", "location"});
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length == RACK_PER_CHASSIS);
      Assert.assertNotNull(result.items[0].resourceObject);
   }

   @Test(dependsOnMethods = { "getAllRacks" })
   public void getChassisGivenRack() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.CHASSIS_TYPE,
            "chassis",
            _rack,
            new String[] {"name", "location"});
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length > 0);
      Assert.assertNotNull(result.items[0].resourceObject);
   }

   @Test(dependsOnMethods = { "getAllChassis" })
   public void getHostsGivenChassis() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.HOST_TYPE,
            "host",
            _chassis,
            new String[] {"name", "location"});
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length > 0);
      Assert.assertNotNull(result.items[0].resourceObject);
      _host = (Host)result.items[0].resourceObject;
   }

   @Test(dependsOnMethods = { "getHostsGivenChassis" })
   public void getChassisGivenHostInverse() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.CHASSIS_TYPE,
            "host",
            _host,
            new String[] {"name", "location"});
      ((RelationalConstraint)qrySpc.resourceSpec.constraint).hasInverseRelation = false;
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length == CHASSIS_PER_HOST);
      Assert.assertNotNull(result.items[0].resourceObject);
   }

   @Test(dependsOnMethods = { "getHostsGivenChassis" })
   public void getChassisGivenHost() {
      QuerySpec qrySpc = QueryUtil.getQuerySpec(
            ChassisRackVSphereDataAdapter.CHASSIS_TYPE,
            "chassis",
            _host,
            new String[] {"name", "location"});
      ResultSet result = getData(qrySpc);
      Assert.assertNotNull(result);
      Assert.assertTrue(result.items.length == CHASSIS_PER_HOST);
      Assert.assertNotNull(result.items[0].resourceObject);
   }

   private ResultSet getData(QuerySpec qrySpc) {
      try {
         RequestSpec request = new RequestSpec();
         request.querySpec = new QuerySpec[] {qrySpc};
         return _adpater.getData(request).resultSet[0];
      } catch (Exception e) {
         System.err.println(e.getMessage());
         Assert.assertTrue(false, "Failure in query execution.");
      }
      return null;
   }
}
