/* Copyright 2012 VMware, Inc. All rights reserved. -- VMware Confidential */
package com.vmware.samples.chassisrackvsphereui {
import com.vmware.core.model.IResourceReference;
import com.vmware.flexutil.proxies.BaseProxy;
import com.vmware.samples.chassisrackvsphereui.model.ChassisInfo;

/**
 * Proxy class for the java ChassisService.
 */
public class ChassisServiceProxy extends BaseProxy
{
   private static const SERVICE_NAME:String = "chassisService";

   // channelUri uses the Web-ContextPath define in MANIFEST.MF (chassis-ui)
   // A secure AMF channel is required because vSphere Web Client uses https
   private static const CHANNEL_URI:String =
         "/" + ChassisRackVSphereUi.contextPath + "/messagebroker/amfsecure";

   /**
    * Create a ChassisServiceProxy with a secure channel.
    */
   public function ChassisServiceProxy() {
      super(SERVICE_NAME, CHANNEL_URI);
   }

   /**
    * Remove a chassis from the inventory.
    *
    * @param chassisRef    The Chassis reference to be deleted.
    * @param callBack      Optional callback method
    * @param callContext   Optional object that is passed back in the callback method
    */
   public function deleteChassis(
         chassisRef:IResourceReference,
         callback:Function = null,
         context:Object = null):void {
      callService("deleteChassis", [chassisRef], callback, context);
   }

   /**
    * Edit a chassis.
    *
    * @param chassisRef    The Chassis reference to edit.
    * @param callBack      Optional callback method
    * @param callContext   Optional object that is passed back in the callback method
    */
   public function editChassis(
         chassisRef:IResourceReference,
         callback:Function = null,
         context:Object = null):void {
      callService("editChassis", [chassisRef], callback, context);
   }

   /**
    * Add a new chassis to the inventory.
    *
    * @param chassisInfo    The data to create a new chassis.
    * @param callBack       Optional callback method
    * @param callContext    Optional object that is passed back in the callback method
    */
   public function createChassis(
         chassisInfo:ChassisInfo,
         callback:Function = null,
         context:Object = null):void {
      callService("createChassis", [chassisInfo], callback, context);
   }

   /**
    * Add a host to a chassis.
    *
    * @param hostRef       The host to be added.
    * @param chassisRef    The chassis where to add the host.
    * @param callBack      Optional callback method
    * @param callContext   Optional object that is passed back in the callback method
    */
   public function addHost(
         host:IResourceReference,
         chassisRef:IResourceReference,
         callback:Function = null,
         context:Object = null):void {
      callService("addHost", [host, chassisRef], callback, context);
   }
}
}

